# [ServiceManager](https://github.com/eserozvataf/servicemanager)

[![npm version][npm-image]][npm-url]
[![npm download][download-image]][npm-url]
[![dependencies][dep-image]][dep-url]
[![license][license-image]][license-url]


## What is the ServiceManager?

ServiceManager is probably the most basic implementation of dependency injection container for JavaScript.


## Quick start

Execute `npm install servicemanager` to install servicemanager and its dependencies into your project directory.


## Usage

To register objects to service manager:

```js
import serviceManager, { ServiceLifetime } from 'servicemanager';
// or const { default: serviceManager, ServiceLifetime } = require('servicemanager');

serviceManager.set(CacheManager, CustomCacheManager, ServiceLifetime.Transient);
serviceManager.set(SessionManager, mySessionManager, ServiceLifetime.Singleton);
```

To get objects back from service manager:

```js
import serviceManager from 'servicemanager';
// or const serviceManager = require('servicemanager').default;

// returns a new instance for CustomCacheManager
const cacheManager = serviceManager.get(CacheManager);

// returns the same session manager object that referenced by mySessionManager
const sessionManager = serviceManager.get(SessionManager);
```

Alternatively, to get all needed instances at once:

```js
import serviceManager from 'servicemanager';
// or const serviceManager = require('servicemanager').default;

const [ cacheManager, sessionManager ] = serviceManager.getRange(CacheManager, SessionManager);
```

...Or, to have them in more promise-friendly way:

```js
import serviceManager from 'servicemanager';
// or const serviceManager = require('servicemanager').default;

serviceManager.ensure([ CacheManager, SessionManager ], (cacheManager, sessionManager) => {
    // awaits promisified generator functions first,
    // then services dependencies as parameters
});
```

*** Note: Service names can be anything including objects, symbols or strings.


## Mechanics

Transient services call generator/dependency target each time they are requested,
whereas, Singleton services are registered when they are defined.

```js
import serviceManager, { ServiceLifetime } from 'servicemanager';
// or const { default: serviceManager, ServiceLifetime } = require('servicemanager');

serviceManager.set('date1', () => new Date(), ServiceLifetime.Transient);
serviceManager.set('date2', new Date(), ServiceLifetime.Singleton);

console.log(serviceManager.get('date1')); // calls and returns new Date()
console.log(serviceManager.get('date1')); // calls and returns new Date() again,
console.log(serviceManager.get('date2')); // no calls, returns stored date.
```


## Todo List

See [GitHub Projects](https://github.com/eserozvataf/servicemanager/projects) for more.


## Requirements

* node.js (https://nodejs.org/)


## License

Apache 2.0, for further details, please see [LICENSE](LICENSE) file


## Contributing

See [contributors.md](contributors.md)

It is publicly open for any contribution. Bugfixes, new features and extra modules are welcome.

* To contribute to code: Fork the repo, push your changes to your fork, and submit a pull request.
* To report a bug: If something does not work, please report it using [GitHub Issues](https://github.com/eserozvataf/servicemanager/issues).


## To Support

[Visit my patreon profile at patreon.com/eserozvataf](https://www.patreon.com/eserozvataf)


[npm-image]: https://img.shields.io/npm/v/servicemanager.svg?style=flat-square
[npm-url]: https://www.npmjs.com/package/servicemanager
[download-image]: https://img.shields.io/npm/dt/servicemanager.svg?style=flat-square
[dep-image]: https://img.shields.io/david/eserozvataf/servicemanager.svg?style=flat-square
[dep-url]: https://github.com/eserozvataf/servicemanager
[license-image]: https://img.shields.io/npm/l/servicemanager.svg?style=flat-square
[license-url]: https://github.com/eserozvataf/servicemanager/blob/master/LICENSE
