"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const serviceLifetime_1 = require("./serviceLifetime");
const get_1 = require("./methods/get");
const set_1 = require("./methods/set");
const getRange_1 = require("./methods/getRange");
const getOrResolve_1 = require("./methods/getOrResolve");
const ensure_1 = require("./methods/ensure");
const filterByTag_1 = require("./methods/filterByTag");
class ServiceManager {
    constructor(resolver) {
        this.items = new Map();
        this.resolver = resolver;
    }
    set(dependency, target, lifetime = serviceLifetime_1.default.Transient, tags = []) {
        return set_1.default(this.items, dependency, target, lifetime, tags);
    }
    get(dependency) {
        return get_1.default(this.items, dependency);
    }
    *getRange(...dependencies) {
        yield* getRange_1.default(this.items, ...dependencies);
    }
    getOrResolve(dependency) {
        return getOrResolve_1.default(this.items, dependency, this.resolver);
    }
    ensure(dependencies, callback) {
        return ensure_1.default(this.items, dependencies, callback, this.resolver);
    }
    *filterByTag(tag) {
        yield* filterByTag_1.default(this.items, tag);
    }
}
exports.default = ServiceManager;
//# sourceMappingURL=serviceManager.js.map